@@ -196,9 +196,8 @@ def root():
         re.purge
         exit()
     allModified = modifiedStaged + modifiedUnstaged
-    workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + [repo.untracked_files for n[1:] in os.listdir(sourceDir)] 
-
-    # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
+    untrackedSrc = [n for n in repo.untracked_files and n.split('/')[1:] in sourceDir]
+    workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
 @root.command()
 def diff():
